Installing Rucio daemons — Rucio 1.2 documentation

# Installing Rucio daemons

## Prerequisites

Rucio server runs on Python 2.6, 2.7.

Platforms: Rucio should run on any Unix-like platform.

## Python Dependencies

Rucio server needs the following python modules:

    SQLAlchemy==1.2.7                                 # db backend
    alembic==0.9.9                                    # Lightweight database migration tool for SQLAlchemy
    Mako==1.0.7                                       # Templating language - Dependency of alembic
    python-editor==1.0.3                              # Programmatically open an editor, capture the result
    flup==1.0.3                                       # Needed to deploy web.py in lighthttpd
    web.py==0.39                                      # Python web framework

All Dependencies are automatically installed with pip.

## Install via docker